summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kcategoriesview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kcategoriesview.h')
-rw-r--r--kmymoney2/views/kcategoriesview.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmymoney2/views/kcategoriesview.h b/kmymoney2/views/kcategoriesview.h
index d37e74d..77fb5d7 100644
--- a/kmymoney2/views/kcategoriesview.h
+++ b/kmymoney2/views/kcategoriesview.h
@@ -65,7 +65,7 @@ class KCategoriesView : public KCategoriesViewDecl
Q_OBJECT
TQ_OBJECT
public:
- KCategoriesView(TQWidget *tqparent=0, const char *name=0);
+ KCategoriesView(TQWidget *parent=0, const char *name=0);
virtual ~KCategoriesView();
@@ -87,7 +87,7 @@ public slots:
protected:
void loadAccounts(void);
- bool loadSubAccounts(KMyMoneyAccountTreeItem* tqparent, const TQStringList& accountList);
+ bool loadSubAccounts(KMyMoneyAccountTreeItem* parent, const TQStringList& accountList);
protected slots:
void slotUpdateProfit(void);
@@ -122,12 +122,12 @@ signals:
/**
* This signal is emitted, when the user selected to reparent the
* account @p acc to be a subordinate account of @p tqparent.
*
* @param acc const reference to account to be reparented
* @param tqparent const reference to new tqparent account
*/
- void reparent(const MyMoneyAccount& acc, const MyMoneyAccount& tqparent);
+ void reparent(const MyMoneyAccount& acc, const MyMoneyAccount& parent);
private:
TQMap<TQString, MyMoneySecurity> m_securityMap;
@@ -122,12 +122,12 @@ signals:
/**
* This signal is emitted, when the user selected to reparent the
- * account @p acc to be a subordinate account of @p tqparent.
+ * account @p acc to be a subordinate account of @p parent.
*
* @param acc const reference to account to be reparented
@@ -122,12 +122,12 @@ signals:
*
* @param acc const reference to account to be reparented
- * @param tqparent const reference to new tqparent account
+ * @param parent const reference to new parent account
*/